pub struct FilesystemBackend<K, V, M = ()>{ /* private fields */ }Expand description
Filesystem storage backend.
Each backend instance is safe for concurrent use. Multiple backend instances or processes must not write to the same directory concurrently.
Implementations
Sourceimpl<K, V, M> FilesystemBackend<K, V, M>
impl<K, V, M> FilesystemBackend<K, V, M>
Sourcepub async fn new<P: AsRef<Path>>(base_path: P) -> Result<Self>
pub async fn new<P: AsRef<Path>>(base_path: P) -> Result<Self>
Create a new filesystem backend with the given base path.
Sourcepub fn with_max_snapshot_bytes(self, max_snapshot_bytes: u64) -> Self
pub fn with_max_snapshot_bytes(self, max_snapshot_bytes: u64) -> Self
Set the maximum accepted and generated snapshot size in bytes.
A zero-byte limit is permitted but makes every snapshot write fail.